@@ -1,11 +1,13 @@
-from deephaven.plugin import Registration
+from deephaven import numpy as dhnp
+from deephaven.plugin import Registration, Callback
 from deephaven.table_listener import listen
 from importlib import resources
 import matplotlib.pyplot as plt
 from matplotlib.animation import Animation
 import itertools
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
+
 
 def _init_theme():
     # Set the Deephaven style globally.
@@ -16,14 +18,16 @@ def _init_theme():
     with resources.path(__package__, 'deephaven.mplstyle') as p:
         plt.style.use(['dark_background',p])
 
+
 class MatplotlibRegistration(Registration):
     @classmethod
-    def register_into(cls, callback: Registration.Callback) -> None:
+    def register_into(cls, callback: Callback) -> None:
         _init_theme()
         plt.switch_backend('AGG')
         from . import figure_type
         callback.register(figure_type.FigureType)
 
+
 class TableEventSource:
     """
     Makes an event source for matplotlib that triggers whenever Deephaven Table updates.
@@ -87,6 +91,7 @@ class TableEventSource:
             self._listener.stop()
             self._listener = None
 
+
 class TableAnimation(Animation):
     """
     Makes an animation by calling a function *func* whenever the Deephaven Table *table* is updated.
@@ -128,7 +133,7 @@ class TableAnimation(Animation):
             self._args = ()
         self._func = func
         self._table = table
-        if not columns:
+        if columns is None:
             self._columns = [column.name for column in table.columns]
         else:
             self._columns = columns
@@ -156,5 +161,5 @@ class TableAnimation(Animation):
     def _draw_frame(self, framedata):
         data = {}
         for column in self._columns:
-            data[column] = self._table.j_table.getColumn(column).getDirect()
+            data[column] = dhnp.to_numpy(self._table, [column])[:, 0]
         self._func(data, self._last_update, *self._args)
\ No newline at end of file
